__all__ = [
    "NUKE_COLOR",
    "THERMAL_COLOR",
    "WIND_COLOR",
    "SOLAR_COLOR",
    "HYDRO_COLOR",
    "NUKE_ID",
    "THERMAL_ID",
    "WIND_ID",
    "SOLAR_ID",
    "HYDRO_ID",
    "TYPE_GEN",
    "COLOR_GEN",
    "BasePlot",
]

from grid2op.PlotGrid.config import *
from grid2op.PlotGrid.BasePlot import BasePlot

# Conditional exports for optional dependencies
try:
    from grid2op.PlotGrid.PlotMatplot import PlotMatplot

    __all__.append("PlotMatplot")
except ImportError:
    pass  # Silent fail because it is optional
try:
    from grid2op.PlotGrid.PlotPlotly import PlotPlotly

    __all__.append("PlotPlotly")
except ImportError:
    pass  # Silent fail because it is optional



# Copyright (c) 2019-2023, RTE (https://www.rte-france.com)
# See AUTHORS.txt
# This Source Code Form is subject to the terms of the Mozilla Public License, version 2.0.
# If a copy of the Mozilla Public License, version 2.0 was not distributed with this file,
# you can obtain one at http://mozilla.org/MPL/2.0/.
# SPDX-License-Identifier: MPL-2.0
# This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.

from grid2op.Chronics.handlers.baseHandler import BaseHandler


class DoNothingHandler(BaseHandler):
    """This is the specific types of handler that does nothing.
    
    You can use if for any data type that you want.
    
    """
    def __init__(self, array_name="do nothing") -> None:
        super().__init__(array_name)
    
    def initialize(self, order_backend_prods, names_chronics_to_backend):
        # there is nothing to do for the DoNothingHandler
        pass
    
    def check_validity(self, backend):
        # there is nothing to do for the DoNothingHandler
        pass
    
    def load_next(self, dict):
        # there is nothing to do for the DoNothingHandler
        pass
        
    def done(self):
        # there is nothing to do for the DoNothingHandler
        return False
        
    def forecast(self,
                 forecast_horizon_id,
                 inj_dict_env,
                 inj_dict_previous_forecast,
                 # eg gen_p_handler if this is set to gen_p_for_handler:
                 env_handler,  
                 # list of the 4 env handlers: (load_p_handler, load_q_handler, gen_p_handler, gen_v_handler)
                 env_handlers):
        # there is nothing to do for the DoNothingHandler
        return None
    
    def load_next_maintenance(self):
        return None, None
    
    def load_next_hazard(self):
        return None
    


# Copyright (c) 2019-2020, RTE (https://www.rte-france.com)
# See AUTHORS.txt
# This Source Code Form is subject to the terms of the Mozilla Public License, version 2.0.
# If a copy of the Mozilla Public License, version 2.0 was not distributed with this file,
# you can obtain one at http://mozilla.org/MPL/2.0/.
# SPDX-License-Identifier: MPL-2.0
# This file is part of Grid2Op, Grid2Op a testbed platform to model sequential decision making in power systems.

# this files present utilitary class for handling the folder where data are stored mainly
import os
import json

DEFAULT_PATH_CONFIG = os.path.expanduser("~/.grid2opconfig.json")
DEFAULT_PATH_DATA = os.path.expanduser("~/data_grid2op")
KEY_DATA_PATH = "data_path"

if os.path.exists(DEFAULT_PATH_CONFIG):
    with open(DEFAULT_PATH_CONFIG, "r") as f:
        dict_ = json.load(f)

    if KEY_DATA_PATH in dict_:
        DEFAULT_PATH_DATA = os.path.abspath(dict_[KEY_DATA_PATH])


def _create_path_folder(data_path):
    if not os.path.exists(data_path):
        try:
            os.mkdir(data_path)
        except Exception as exc_:
            raise RuntimeError(
                'Impossible to create a directory in "{}". Make sure you can write here. If you don\'t '
                'have writing permissions there, you can edit / create a config file in "{}"'
                'and set the "data_path" to point to a path where you can store data.'
                "".format(data_path, DEFAULT_PATH_CONFIG)
            )



__all__ = [
    "BaseEnv",
    "Environment",
    "BaseMultiProcessEnvironment",
    "SingleEnvMultiProcess",
    "MultiEnvMultiProcess",
    "MultiMixEnvironment",
    "TimedOutEnvironment"
]

from grid2op.Environment.baseEnv import BaseEnv
from grid2op.Environment.environment import Environment
from grid2op.Environment.baseMultiProcessEnv import BaseMultiProcessEnvironment
from grid2op.Environment.singleEnvMultiProcess import SingleEnvMultiProcess
from grid2op.Environment.multiEnvMultiProcess import MultiEnvMultiProcess
from grid2op.Environment.multiMixEnv import MultiMixEnvironment
from grid2op.Environment.timedOutEnv import TimedOutEnvironment
